## ----setup, include = FALSE---------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>",
  echo = TRUE,
  warning = FALSE,
  message = FALSE
)

## ----style, echo = FALSE, results = 'asis'------------------------------------
BiocStyle::markdown()

## ----load_data, echo = TRUE---------------------------------------------------
library(Pirat)
data(subbouyssie)

## ----setseed------------------------------------------------------------------
set.seed(12345)

## ----impute-------------------------------------------------------------------
imp.res <- my_pipeline_llkimpute(subbouyssie)

## ----test1--------------------------------------------------------------------
head(imp.res$data.imputed[ ,1:5])

## -----------------------------------------------------------------------------
imp.res$params

## -----------------------------------------------------------------------------
data(subropers)
plot_pep_correlations(subropers, titlename = "Ropers2021")

## -----------------------------------------------------------------------------
data(subropers)
imp.res = pipeline_llkimpute(subropers, extension = "2")

## -----------------------------------------------------------------------------
idx.sing.pg = which(colSums(subropers$adj) == 1)
idx.sing.pep = which(rowSums(subropers$adj[, idx.sing.pg]) >= 1)
imp.res$data.imputed[, idx.sing.pep]

## -----------------------------------------------------------------------------
imp.res = my_pipeline_llkimpute(subropers, extension = "S")

## -----------------------------------------------------------------------------
idx.sing.pg = which(colSums(subropers$adj) == 1)
idx.sing.pep = which(rowSums(subropers$adj[, idx.sing.pg]) >= 1)
imp.res$data.imputed[, idx.sing.pep]

## -----------------------------------------------------------------------------
imp.res = my_pipeline_llkimpute(subropers,
                             extension = "T",
                             rna.cond.mask = 1:nrow(subropers$peptides_ab),
                             pep.cond.mask = 1:nrow(subropers$peptides_ab),
                             max.pg.size.pirat.t = 1)

## -----------------------------------------------------------------------------
idx.sing.pg = which(colSums(subropers$adj) == 1)
idx.sing.pep = which(rowSums(subropers$adj[, idx.sing.pg]) >= 1)
imp.res$data.imputed[, idx.sing.pep]

## -----------------------------------------------------------------------------
imp.res = my_pipeline_llkimpute(subropers,
                             extension = "T",
                             rna.cond.mask = rep(1:6, each = 3),
                             pep.cond.mask = rep(1:6, each = 3),
                             max.pg.size.pirat.t = 1)

## -----------------------------------------------------------------------------
sessionInfo()

